@@ -12,6 +12,16 @@ var booleanOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!bool)::true\n",
 		},
 	},
+	{
+		description:    "\"yes\" and \"no\" are strings",
+		subdescription: "In the yaml 1.2 standard, support for yes/no as booleans was dropped - they are now considered strings. See '10.2.1.2. Boolean' in https://yaml.org/spec/1.2.2/",
+		document:       `[yes, no]`,
+		expression:     `.[] | tag`,
+		expected: []string{
+			"D0, P[0], (!!str)::!!str\n",
+			"D0, P[1], (!!str)::!!str\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   "b: hi",
