@@ -35,6 +35,13 @@ steps:
 `
 
 var traversePathOperatorScenarios = []expressionScenario{
+	{
+		skipDoc:     true,
+		description: "splat empty map",
+		document:    "{}",
+		expression:  ".[]",
+		expected:    []string{},
+	},
 	{
 		skipDoc:    true,
 		document:   `[[1]]`,
